@@ -22,8 +22,10 @@ class Range(object):
 			raise Exception("Column index out of bounds")
 		self.worksheet = worksheet
 		self.is_cell = (self._start == self._end)
+		
 		self.is_row = (self._end[1] == float('inf') and self._start[0] == self._end[0] and self._start[1] == 1)
 		self.is_column = (self._end[0] == float('inf') and self._start[1] == self._end[1] and self._start[0] == 1)
+ 		
 		self.x = (self._start[0] if self.is_row or self.is_cell else None)
 		self.y = (self._start[1] if self.is_column or self.is_cell else None)
 		self.height = (self._end[0] - self._start[0] + 1)
@@ -165,6 +167,8 @@ class Range(object):
 	def __getitem__(self, key):
 		if self.is_row:
 			# return the key'th column
+			if isinstance(key, six.string_types):
+				key = Range.string_to_coordinate(key)
 			return Range((self.x, key), (self.x, key), self.worksheet, validate=False)
 		elif self.is_column:
 			#return the key'th row
@@ -182,17 +186,24 @@ class Range(object):
 	def string_to_coordinate(s):
 		# Convert a base-26 name to integer
 		y = 0
+		l = len(s)
 		for index, c in enumerate(s):
 			if ord(c) < Range.A or ord(c) > Range.Z:
 				s = s[index:]
 				break
 			y *= 26
 			y += ord(c) - Range.A + 1
-		return (int(s), y)
+		if len(s) == l:
+			return y
+		else:
+			return (int(s), y)
 
 	_cts_cache = {}
 	@staticmethod
 	def coordinate_to_string(coord):
+		if coord[1] == float('inf'):
+			return 'IV%s' % str(coord[0])
+		
 		# convert an integer to base-26 name
 		y = coord[1] - 1
 		if y not in Range._cts_cache:
